==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/porte_plume/lang/barreoutils_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/barreoutils?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'À intypen',
	'barre_adresse' => 'Adres',
	'barre_aide' => 'Gebruik typografische sneltoetsen om uw  lay-out te verbeteren',
	'barre_alignerdroite' => 'Paragraaf [/rechts uitlijnen/]',
	'barre_ancres' => 'Beheer van ankers',
	'barre_barre' => 'Tekst doorstrepen',
	'barre_bulle' => 'Helpscherm',
	'barre_c_cedille_maj' => 'Ç intypen',
	'barre_cadre' => 'In een &lt;cadre&gt;tekstopslag zone&lt;/cadre&gt; plaatsen',
	'barre_caracteres' => 'Speciale tekens',
	'barre_centrer' => 'Paragraaf [|centreren|]',
	'barre_chercher' => 'Zoeken / Vervangen',
	'barre_clean' => 'Alle html tags uit de code wissen',
	'barre_code' => 'Een &lt;code&gt; informaticuscode &lt;/code&gt; formatteren',
	'barre_desindenter' => 'Lijst laten terugspringen ',
	'barre_e_accent_aigu' => 'É intypen',
	'barre_e_accent_grave' => 'È intypen',
	'barre_ea' => 'æ intypen',
	'barre_ea_maj' => 'Æ intypen',
	'barre_encadrer' => 'Paragraaf [(omlijnen)]',
	'barre_eo' => 'œ intypen',
	'barre_eo_maj' => 'Œ intypen',
	'barre_euro' => '€ intypen',
	'barre_exposant' => 'Tekst in &lt;sup&gt;exponent&lt;/sup&gt; zetten',
	'barre_formatages_speciaux' => 'Speciale formattering ',
	'barre_galerie' => 'Galerij opendoen',
	'barre_gestion_anc_bulle' => 'Helpscherm anker',
	'barre_gestion_anc_caption' => 'Ankerbeheer ',
	'barre_gestion_anc_cible' => 'Doelanker ',
	'barre_gestion_anc_inserer' => 'Als anker verwerken',
	'barre_gestion_anc_nom' => 'Ankernaam ',
	'barre_gestion_anc_pointer' => 'Naar een anker linken ',
	'barre_gestion_caption' => 'Legend en Samenvatting ',
	'barre_gestion_colonne' => 'Aantal kolommen ',
	'barre_gestion_cr_casse' => 'Letterkast respecteren',
	'barre_gestion_cr_changercasse' => 'Letterkast veranderen',
	'barre_gestion_cr_changercassemajuscules' => 'Hoofdletter zetten',
	'barre_gestion_cr_changercasseminuscules' => 'Onderkast zetten',
	'barre_gestion_cr_chercher' => 'Zoeken',
	'barre_gestion_cr_entier' => 'Volledige woord',
	'barre_gestion_cr_remplacer' => 'Vervangen',
	'barre_gestion_cr_tout' => 'Alles vervangen',
	'barre_gestion_entete' => 'Hoofd',
	'barre_gestion_ligne' => 'Aantal lijnen',
	'barre_gestion_taille' => 'Vaste grootte',
	'barre_glossaire' => 'Linken naar het  [?woordenlijst] (Wikipedia)',
	'barre_gras' => 'In het {{vet}} schrijven',
	'barre_guillemets' => 'In « aanhalingsteken » sluiten',
	'barre_guillemets_simples' => 'In  “2de niveau aanhalingsteken” sluiten',
	'barre_indenter' => 'Lijst inspringen',
	'barre_inserer_cadre' => 'Een vooraf geformatteerde code invoegen (cadre)',
	'barre_inserer_caracteres' => 'Speciale tekens intypen',
	'barre_inserer_code' => 'Een informaticus code invoegen (code)',
	'barre_intertitre' => 'Als {{{tussenkop}}} zetten',
	'barre_italic' => '{Cursief} zetten',
	'barre_langue' => 'Taalverkorting',
	'barre_lien' => 'In [hyperlink->http://...] verwerken',
	'barre_lien_externe' => 'Externe link ',
	'barre_lien_input' => 'Gelieve het adres van je link in te geven (Internet adres zoals http://www.monsite.com, email adres, of gewoon het nummer van een artikel uit deze site).',
	'barre_liste_ol' => 'Een genummerde lijst zetten ',
	'barre_liste_ul' => 'In lijst zetten',
	'barre_lorem_ipsum' => 'Een lege paragraaf aanmaken',
	'barre_lorem_ipsum_3' => 'Drie lege paragrafen zetten',
	'barre_miseenevidence' => 'Tekst [*goed zichtbaar neerleggen*]',
	'barre_note' => 'In [[Voetnoot]] verwerken',
	'barre_paragraphe' => 'Een paragraaf aanmaken',
	'barre_petitescapitales' => 'Tekst in &lt;sc&gt;kleine hoofdletters&lt;/sc&gt; zetten',
	'barre_poesie' => 'Als een &lt;poesie&gt;poëzie&lt;/poesie&gt; formatteren ',
	'barre_preview' => 'Preview-modus',
	'barre_quote' => '<quote>Een boodschap citeren</quote>',
	'barre_stats' => 'Statistieken van de tekst wijzen',
	'barre_tableau' => 'Een table (vooraf te selecteren) aanmaken/verbeteren',

	// C
	'config_info_enregistree' => 'Configuratie opgeslagen',

	// E
	'editer' => 'Redigeren',
	'explication_barre_outils_public' => 'De CSS- en Javascript-scripten   van de werkbalken (Penhouder plug-in) zijn op de publieke site bruikbaar
	en maken het zo mogelijk om ze op de forumformuliers te gebriken,
	de publieke potloden (plug-in) of nog andere plugins, of hun configuratie het zo voorziet.',
	'explication_barre_outils_public_2' => 'Je mag kiezen deze scripts niet te laten laden
	om de grootte van de publieke pagina’s te verminderen.
	In dit geval zal geen werkbalk in de publieke site beschikbaar 
        zijn, onafhankelijk van de configuraties van de fora, 
        potloden en andere plugins.',

	// I
	'info_barre_outils_public' => 'Publieke werkbalk',
	'info_porte_plume_titre' => 'Werkbalken configureren ',

	// L
	'label_barre_outils_public_non' => 'De scripts van de werkbalken op de publieke site NIET laden ',
	'label_barre_outils_public_oui' => 'De scripts van de werkbalk op de publieke site laden',

	// V
	'voir' => 'Zien'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/porte_plume/lang/barreoutils_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/barreoutils?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'À intypen',
	'barre_adresse' => 'Adres',
	'barre_aide' => 'Gebruik typografische sneltoetsen om uw  lay-out te verbeteren',
	'barre_alignerdroite' => 'Paragraaf [/rechts uitlijnen/]',
	'barre_ancres' => 'Beheer van ankers',
	'barre_barre' => 'Tekst doorstrepen',
	'barre_bulle' => 'Helpscherm',
	'barre_c_cedille_maj' => 'Ç intypen',
	'barre_cadre' => 'In een &lt;cadre&gt;tekstopslag zone&lt;/cadre&gt; plaatsen',
	'barre_caracteres' => 'Speciale tekens',
	'barre_centrer' => 'Paragraaf [|centreren|]',
	'barre_chercher' => 'Zoeken / Vervangen',
	'barre_clean' => 'Alle html tags uit de code wissen',
	'barre_code' => 'Een &lt;code&gt; informaticuscode &lt;/code&gt; formatteren',
	'barre_desindenter' => 'Lijst laten terugspringen ',
	'barre_e_accent_aigu' => 'É intypen',
	'barre_e_accent_grave' => 'È intypen',
	'barre_ea' => 'æ intypen',
	'barre_ea_maj' => 'Æ intypen',
	'barre_encadrer' => 'Paragraaf [(omlijnen)]',
	'barre_eo' => 'œ intypen',
	'barre_eo_maj' => 'Œ intypen',
	'barre_euro' => '€ intypen',
	'barre_exposant' => 'Tekst in &lt;sup&gt;exponent&lt;/sup&gt; zetten',
	'barre_formatages_speciaux' => 'Speciale formattering ',
	'barre_galerie' => 'Galerij opendoen',
	'barre_gestion_anc_bulle' => 'Helpscherm anker',
	'barre_gestion_anc_caption' => 'Ankerbeheer ',
	'barre_gestion_anc_cible' => 'Doelanker ',
	'barre_gestion_anc_inserer' => 'Als anker verwerken',
	'barre_gestion_anc_nom' => 'Ankernaam ',
	'barre_gestion_anc_pointer' => 'Naar een anker linken ',
	'barre_gestion_caption' => 'Legend en Samenvatting ',
	'barre_gestion_colonne' => 'Aantal kolommen ',
	'barre_gestion_cr_casse' => 'Letterkast respecteren',
	'barre_gestion_cr_changercasse' => 'Letterkast veranderen',
	'barre_gestion_cr_changercassemajuscules' => 'In hoofdletters zetten',
	'barre_gestion_cr_changercasseminuscules' => 'In onderkast zetten',
	'barre_gestion_cr_chercher' => 'Zoeken',
	'barre_gestion_cr_entier' => 'Volledige woord',
	'barre_gestion_cr_remplacer' => 'Vervangen',
	'barre_gestion_cr_tout' => 'Alles vervangen',
	'barre_gestion_entete' => 'Hoofd',
	'barre_gestion_ligne' => 'Aantal lijnen',
	'barre_gestion_taille' => 'Vaste grootte',
	'barre_glossaire' => 'Linken naar het  [?woordenlijst] (Wikipedia)',
	'barre_gras' => 'In het {{vet}} schrijven',
	'barre_guillemets' => 'In « aanhalingsteken » sluiten',
	'barre_guillemets_simples' => 'In  “2de niveau aanhalingsteken” sluiten',
	'barre_indenter' => 'Lijst inspringen',
	'barre_inserer_cadre' => 'Een vooraf geformatteerde code invoegen (cadre)',
	'barre_inserer_caracteres' => 'Speciale tekens intypen',
	'barre_inserer_code' => 'Een informaticus code invoegen (code)',
	'barre_intertitre' => 'Als {{{tussenkop}}} zetten',
	'barre_italic' => '{Cursief} zetten',
	'barre_langue' => 'Taalverkorting',
	'barre_lien' => 'In [hyperlink->http://...] verwerken',
	'barre_lien_externe' => 'Externe link ',
	'barre_lien_input' => 'Gelieve het adres van je link in te geven (Internet adres zoals http://www.monsite.com, email adres, of gewoon het nummer van een artikel uit deze site).',
	'barre_liste_ol' => 'Een genummerde lijst zetten ',
	'barre_liste_ul' => 'In lijst zetten',
	'barre_lorem_ipsum' => 'Een lege paragraaf aanmaken',
	'barre_lorem_ipsum_3' => 'Drie lege paragrafen zetten',
	'barre_miseenevidence' => 'Tekst [*goed zichtbaar neerleggen*]',
	'barre_note' => 'In [[Voetnoot]] verwerken',
	'barre_paragraphe' => 'Een paragraaf aanmaken',
	'barre_petitescapitales' => 'Tekst in &lt;sc&gt;kleine hoofdletters&lt;/sc&gt; zetten',
	'barre_poesie' => 'Als een &lt;poesie&gt;poëzie&lt;/poesie&gt; formatteren ',
	'barre_preview' => 'Preview-modus',
	'barre_quote' => '<quote>Een boodschap citeren</quote>',
	'barre_stats' => 'Statistieken van de tekst wijzen',
	'barre_tableau' => 'Een tabel (vooraf te selecteren) aanmaken/verbeteren',

	// C
	'config_info_enregistree' => 'Configuratie opgeslagen',

	// E
	'editer' => 'Redigeren',
	'explication_barre_outils_public' => 'De CSS- en Javascript-scripten   van de werkbalken (Penhouder plug-in) zijn op de publieke site bruikbaar
	en maken het zo mogelijk om ze op de forumformuliers te gebriken,
	de publieke potloden (plug-in) of nog andere plugins, of hun configuratie het zo voorziet.',
	'explication_barre_outils_public_2' => 'Je mag kiezen deze scripts niet te laten laden
	om de grootte van de publieke pagina’s te verminderen.
	In dit geval zal geen werkbalk in de publieke site beschikbaar 
        zijn, onafhankelijk van de configuraties van de fora, 
        potloden en andere plugins.',

	// I
	'info_barre_outils_public' => 'Publieke werkbalk',
	'info_porte_plume_titre' => 'Werkbalken configureren ',

	// L
	'label_barre_outils_public_non' => 'De scripts van de werkbalken op de publieke site NIET laden ',
	'label_barre_outils_public_oui' => 'De scripts van de werkbalk op de publieke site laden',

	// V
	'voir' => 'Zien'
);

?>
